@@ -2,6 +2,7 @@ import pytest
 import asyncio
 import trio
 import sniffio
+from async_generator import async_generator, yield_
 from trio_asyncio import aio_as_trio, trio_as_aio
 from tests import aiotest
 from functools import partial
@@ -302,7 +303,7 @@ class TestCalls(aiotest.TestCase):
         async def cancelled_trio(seen):
             seen.flag |= 1
             await trio.sleep(0.01)
-            scope = trio.hazmat.current_task()._cancel_stack[-1]
+            scope = trio.hazmat.current_task()._cancel_status._scope
             scope.cancel()
             seen.flag |= 2
             await trio.sleep(0.01)
@@ -329,7 +330,7 @@ class TestCalls(aiotest.TestCase):
             return f  # contains error
 
         async def check_cancel(proc, seen):
-            with trio.open_cancel_scope() as scope:
+            with trio.CancelScope() as scope:
                 with pytest.raises(asyncio.CancelledError):
                     await self.call_t_a(proc, seen, loop=loop)
             assert not scope.cancel_called
@@ -359,7 +360,7 @@ class TestCalls(aiotest.TestCase):
             return f  # contains error
 
         async def check_cancel(proc, seen):
-            with trio.open_cancel_scope() as scope:
+            with trio.CancelScope() as scope:
                 with pytest.raises(asyncio.CancelledError):
                     await self.call_t_a_depr(proc, seen, loop=loop)
             assert not scope.cancel_called
@@ -525,10 +526,11 @@ class TestCalls(aiotest.TestCase):
 
     @pytest.mark.trio
     async def test_trio_asyncio_generator(self, loop):
+        @async_generator
         async def dly_asyncio():
-            yield 1
+            await yield_(1)
             await asyncio.sleep(0.01, loop=loop)
-            yield 2
+            await yield_(2)
 
         with test_utils.deprecate(self):
             res = await async_gen_to_list(loop.wrap_generator(dly_asyncio))
@@ -536,10 +538,11 @@ class TestCalls(aiotest.TestCase):
 
     @pytest.mark.trio
     async def test_trio_asyncio_generator_with_error(self, loop):
+        @async_generator
         async def dly_asyncio():
-            yield 1
+            await yield_(1)
             raise RuntimeError("I has an owie")
-            yield 2
+            await yield_(2)
 
         with test_utils.deprecate(self):
             with pytest.raises(RuntimeError) as err:
@@ -548,8 +551,9 @@ class TestCalls(aiotest.TestCase):
 
     @pytest.mark.trio
     async def test_trio_asyncio_generator_with_cancellation(self, loop):
+        @async_generator
         async def dly_asyncio(hold, seen):
-            yield 1
+            await yield_(1)
             seen.flag |= 1
             await hold.wait()
 
@@ -569,10 +573,11 @@ class TestCalls(aiotest.TestCase):
 
     @pytest.mark.trio
     async def test_trio_asyncio_iterator(self, loop):
+        @async_generator
         async def slow_nums():
             for n in range(1, 6):
-                asyncio.sleep(0.01, loop=loop)
-                yield n
+                await asyncio.sleep(0.01, loop=loop)
+                await yield_(n)
 
         sum = 0
         async for n in aio_as_trio(slow_nums()):
@@ -581,10 +586,11 @@ class TestCalls(aiotest.TestCase):
 
     @pytest.mark.trio
     async def test_trio_asyncio_iterator_depr(self, loop):
+        @async_generator
         async def slow_nums():
             for n in range(1, 6):
-                asyncio.sleep(0.01, loop=loop)
-                yield n
+                await asyncio.sleep(0.01, loop=loop)
+                await yield_(n)
 
         sum = 0
         # with test_utils.deprecate(self): ## not yet
